Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(301)

Unified Diff: runtime/bin/eventhandler_fuchsia.cc

Issue 2433833005: Fuchsia: Fix eventhandler for changed syscall return (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/eventhandler_fuchsia.cc
diff --git a/runtime/bin/eventhandler_fuchsia.cc b/runtime/bin/eventhandler_fuchsia.cc
index 2a611647f0bf13e0442d3ecf6c2d71b5674ef8e9..ff03f14ab9e9f756a9efff034b89e54dc3859d4e 100644
--- a/runtime/bin/eventhandler_fuchsia.cc
+++ b/runtime/bin/eventhandler_fuchsia.cc
@@ -75,9 +75,9 @@ void EventHandlerImplementation::HandleInterruptFd() {
UNIMPLEMENTED();
}
}
- // status == ERR_BAD_STATE when we try to read and there are no messages
- // available, so it is an error if we get here and status != ERR_BAD_STATE.
- if (status != ERR_BAD_STATE) {
+ // status == ERR_SHOULD_WAIT when we try to read and there are no messages
+ // available, so it is an error if we get here and status != ERR_SHOULD_WAIT.
+ if (status != ERR_SHOULD_WAIT) {
FATAL1("mx_msgpipe_read failed: %s\n", mx_status_get_string(status));
}
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698